# find-debuginfo.sh cannot find Scheme source files
%global debug_package %{nil}

%global prerel rc9
%global fullver %{version}%{?prerel:-%{prerel}}

Name:           hop
Version:        3.0.0
Release:        %{?prerel:0.}1%{?prerel:.%{prerel}}%{?dist}.1
Summary:        A web development kit

License:        GPLv2+
URL:            http://hop.inria.fr/
Source0:        ftp://ftp-sop.inria.fr/indes/fp/Hop/%{name}-%{fullver}.tar.gz

# Bigloo is not available on ppc64
ExcludeArch:    ppc64

BuildRequires:  bigloo >= 4.2a
BuildRequires:  avahi-devel
BuildRequires:  mailcap
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  sqlite-devel

%description
Hop is a new programming language designed for the Web 2.0. It is a
higher-order language for programming interactive web applications
such as web agendas, web galleries, music players, etc. Hop can be
viewed as a replacement for traditional graphical toolkits. HOP is
implemented as a Web broker, i.e., a Web server that may act
indifferently as a regular Web server or Web proxy.

HOP features:

    * an extensive set of widgets for programming fancy GUIs.
    * an extensive set of libraries for:
          o handling database accesses.
          o dealing with network connections.
          o parsing wiki documents.
          o supporting various protocols such as IMAP, ICALENDAR, ...
          o supporting various formats such as EXIF, ID3, ...
          o parsing and generating XML documents.
          o ...


%prep
%setup -q -n %{name}-%{fullver}

# fix encodings
for fil in ChangeLog share/aes.js share/sha1.js \
    weblets/home/articles/hop-lang/article.html \
    weblets/home/articles/hop-multimedia/article.html \
    weblets/home/articles/hop-perfs/article.html \
    weblets/home/articles/hss/article.xhtml; do
  iconv -f ISO-8859-1 -t UTF-8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done


%build
# optflags inherited from Bigloo
./configure \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --mandir=%{_mandir} \
  --etcdir=%{_sysconfdir}
# Use of %%{?_smp_mflags} sometimes fails
make


%install
make install DESTDIR=$RPM_BUILD_ROOT
# remove
# mark sofiles executable so they are detected by find-debuginfo.sh
# http://fedoraproject.org/wiki/Packaging:Debuginfo#Useless_or_incomplete_debuginfo_packages_due_to_packaging_issues
chmod a+x $RPM_BUILD_ROOT%{_libdir}/hop/*/*.so.*
# remove static archives
rm $RPM_BUILD_ROOT%{_libdir}/hop/*/*.a

# manually strip binaries and libraries, since find-debuginfo.sh is not run
strip $RPM_BUILD_ROOT%{_bindir}/* $RPM_BUILD_ROOT%{_libdir}/hop/*/lib*.so.* \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/lib/.libs/*/*/*.so.*

# fix permissions
chmod 0644 \
      $RPM_BUILD_ROOT%{_datadir}/hop/site-lisp/hopjs.el \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/package.json \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/doc/*.md \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/hss/*.hss \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/lib/{.afile,Makefile} \
      $RPM_BUILD_ROOT%{_libdir}/hop/*/node_modules/*/lib/*.{hop,js,sch}


%files
%doc LICENSE ChangeLog README
%{_bindir}/hop*
%{_libdir}/hop/
%{_datadir}/hop/
%{_mandir}/man1/hop*.1*
%config(noreplace) %{_sysconfdir}/hop*rc.hop


%changelog
* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-0.1.rc9.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Dec 23 2015 Jerry James <loganjerry@gmail.com> - 3.0.0-0.1.rc9
- Update to 3.0.0-rc9 for bigloo 4.2c
- Drop obsoletes for long dead versions of Fedora

* Wed Oct 28 2015 Jerry James <loganjerry@gmail.com> - 3.0.0-0.1.rc4
- Update to 3.0.0-rc4 for bigloo 4.2b (bz 966006)

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.0-1.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Sep 04 2014 Pádraig Brady <pbrady@redhat.com> - 2.5.0-1.3
- rebuild for libunistring soname bump

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.0-1.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.0-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Mar  4 2014 Jerry James <loganjerry@gmail.com> - 2.5.0-1
- Update to 2.5.0

* Thu Feb 20 2014 Jerry James <loganjerry@gmail.com> - 2.4.2-1
- Update to 2.4.2

* Fri Aug  2 2013 Jerry James <loganjerry@gmail.com> - 2.4.1-2
- Rebuild for Bigloo 4.0b

* Fri Jun 14 2013 Michel Salim <salimma@fedoraproject.org> - 2.4.1-1
- Update to 2.4.1

* Mon Feb 18 2013 Jerry James <loganjerry@gmail.com> - 2.4.0-1
- Update to final 2.4.0 release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-0.3.rc4.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Nov 19 2012 Michel Salim <salimma@fedoraproject.org> - 2.4.0-0.3.rc4
- Update to 2.4.0-rc4

* Thu Oct 25 2012 Michel Salim <salimma@fedoraproject.org> - 2.4.0-0.2.rc3
- Update to 2.4.0-rc3

* Thu Oct 25 2012 Michel Salim <salimma@fedoraproject.org> - 2.4.0-0.1.rc2
- Update to 2.4.0-rc2

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul  3 2012 Michel Salim <salimma@fedoraproject.org> - 2.3.0-2
- Rebuild for Bigloo 3.8c

* Thu May  3 2012 Michel Salim <salimma@fedoraproject.org> - 2.3.0-1
- Update to final 2.3.0 release
- ExcludeArch ppc64, matching Bigloo
- Add BR on sqlite-devel
- %%prep: Explicitly specify encoding conversion target
- no longer redundantly clean buildroot in %%install
- Disable debuginfo generation for now

* Sat Apr  7 2012 Michel Salim <salimma@fedoraproject.org> - 2.3.0-0.rc2.1
- Initial package
